#ifndef KONTINUIDADJABATA_H
#define KONTINUIDADJABATA_H

#include <qmessagebox.h>
#include <qtooltip.h>
#include <qcombobox.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include <qbuttongroup.h>
#include <qcheckbox.h>
#include <qaccel.h>
#include <qstrlist.h>

#include <kapp.h>
#include <kmessagebox.h>
#include <kmainwindow.h>
#include <ktabctl.h>
#include <kcmdlineargs.h>

#include "jabatoSchedule.h"
#include "jabatoFileFeeder.h"
#include "jabatoSound.h"


class KontinuidadJabata : public KMainWindow 
{
    Q_OBJECT

public:
    KontinuidadJabata (JabatoSchedule *, char *dev=NULL, char *output = NULL, int kjmode=0);
    ~KontinuidadJabata ();

    QAccel *accel;

protected:
    void resizeEvent (QResizeEvent *event);

public slots:
    void playORstop ();
    void forwardSound ();
    void record ();
    void stopNow ();

    void recordingStarted (MP3Recorder *);
    void recordingHold (MP3Recorder *);
    void recordingRestarted (MP3Recorder *);
    void recordingFinished (MP3Recorder *);
    
    void playbackFinished (MP3Player *);

    void blockChanged (int index);
    void slotChanged (int index);

    void timeout ();
    void runMixer ();

    void freeDiskOutput (KProcess *, char *, int);

private:
    void PopulateGUI ();
    void create_statusline();

    void refreshCurrentSound();
    void refreshNextSound();
    void refreshCurrentBlock();
    void refreshTimers();

    void nextToCurrent();
    void playNextSound();
    void recordNextSound();
    void recordCurrentSound();
    void lookforNextSound(int blockIndex=-1);
    int  secsLeftByNextSound(int, int, int);
    int  toSecs(int,int,int);

    int csndGrpHeight;
    int blkGrpHeight;
    int sndGrpHeight;

    int kjabatamode;

    long minFreeDiskInBytes;

    int dow, hour, minute, second;  /* dow stands for day of week */

    QPixmap 	  playIcon;
    QPixmap 	  stopIcon;
    QPixmap 	  recIcon;
    QPixmap 	  recStopIcon;
    QPushButton   *playStopButton;
    QPushButton   *recordButton;
    QPushButton   *forwardButton;
    QPushButton   *mixerButton;
    QPushButton   *stopNowButton;
    QCheckBox	  *onAirCheck;

    QGroupBox 	  *qgTop;
    QGroupBox     *qgCSound;
    QGroupBox     *qgSound;
    QGroupBox     *qgBlock;

    QFrame 	  *qgLevel;
    QFrame 	  *qgFFT;

    KStatusBar    *statusline;
    KShellProcess *freeDiskProcess;
    KShellProcess *shellProcess;

    char programsPath[256];
    char startRecScript[256];
    char holdRecScript[256];
    char restartRecScript[256];
    char finishRecScript[256];

    MP3Player          *mp3player;
    MP3Recorder        *mp3recorder;
    JabatoSchedule     *schedule;
    JabatoFileFeeder   *filefeeder;

    JabatoSound    *currentSound;
    JabatoSound    *nextSound;

    bool changingBlock;
    bool autoRecording;
    bool autoRecorded;
    bool recordPending;
    int recorderTries;
    int clksWaitingToRecord;

    int	status;

    char text[255]; /* text for formatting labels */

    QLabel	*lbCSndName;
    QLabel	*lbCSndTime;
    QLabel	*lbCSndDir;
    QLabel	*lbCSndSubdir;
    QLabel	*lbCSndPath;

    QComboBox	*cbBlocks;
    QLabel	*lbBlkSonidos;
    QLabel	*lbBlkBegin;
    QLabel	*lbBlkEnd;
    QComboBox	*cbSlots;

    QLabel	*lbBlkBeganAt;
    QLabel	*lbBlkllFinishAt;
    QLabel	*lbBeganArrow;
    QLabel	*lbFinishArrow;

    QLabel	*lbSndName;
    QLabel	*lbSndTime;
    QLabel	*lbSndDir;
    QLabel	*lbSndSubdir;
    QLabel	*lbSndPath;

};

#endif
